Author: jimtabor
Date: Sat Aug 11 10:29:31 2007
New Revision: 28275
URL:
http://svn.reactos.org/svn/reactos?rev=28275&view=rev
Log:
Removed Ex from NtGdiSetBitmapDimensionEx and NtGdiSetBrushOrgEx.
Modified:
trunk/reactos/dll/win32/gdi32/gdi32.def
trunk/reactos/include/reactos/win32k/ntgdibad.h
trunk/reactos/subsystems/win32/win32k/objects/bitmaps.c
trunk/reactos/subsystems/win32/win32k/objects/brush.c
trunk/reactos/subsystems/win32/win32k/w32ksvc.db
Modified: trunk/reactos/dll/win32/gdi32/gdi32.def
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/gdi32/gdi32.def?…
==============================================================================
--- trunk/reactos/dll/win32/gdi32/gdi32.def (original)
+++ trunk/reactos/dll/win32/gdi32/gdi32.def Sat Aug 11 10:29:31 2007
@@ -532,12 +532,12 @@
SetArcDirection@8
SetBitmapAttributes@8
SetBitmapBits@12=NtGdiSetBitmapBits@12
-SetBitmapDimensionEx@16=NtGdiSetBitmapDimensionEx@16
+SetBitmapDimensionEx@16=NtGdiSetBitmapDimension@16
SetBkColor@8=NtGdiSetBkColor@8
SetBkMode@8=NtGdiSetBkMode@8
SetBoundsRect@12
SetBrushAttributes@8
-SetBrushOrgEx@16=NtGdiSetBrushOrgEx@16
+SetBrushOrgEx@16=NtGdiSetBrushOrg@16
SetColorAdjustment@8
SetColorSpace@8
SetDCBrushColor@8
Modified: trunk/reactos/include/reactos/win32k/ntgdibad.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/include/reactos/win32k/ntg…
==============================================================================
--- trunk/reactos/include/reactos/win32k/ntgdibad.h (original)
+++ trunk/reactos/include/reactos/win32k/ntgdibad.h Sat Aug 11 10:29:31 2007
@@ -621,29 +621,11 @@
BOOL ForceBackground
);
-/* Use NtGdiSetBitmapDimension. */
-BOOL
-STDCALL
-NtGdiSetBitmapDimensionEx (
- HBITMAP hBitmap,
- INT Width,
- INT Height,
- LPSIZE Size
- );
-
/* Needs to be done in user-mode, using shared GDI Object Attributes. */
COLORREF STDCALL NtGdiSetBkColor (HDC hDC, COLORREF Color);
/* Needs to be done in user-mode, using shared GDI Object Attributes. */
INT STDCALL NtGdiSetBkMode(HDC hDC, INT backgroundMode);
-
-/* Use NtGdiSetBrushOrg. */
-BOOL STDCALL
-NtGdiSetBrushOrgEx(
- HDC hDC,
- INT XOrg,
- INT YOrg,
- LPPOINT Point);
/* Use NtGdiDoPalette with GdiPalSetColorTable, TRUE. */
UINT
Modified: trunk/reactos/subsystems/win32/win32k/objects/bitmaps.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/subsystems/win32/win32k/ob…
==============================================================================
--- trunk/reactos/subsystems/win32/win32k/objects/bitmaps.c (original)
+++ trunk/reactos/subsystems/win32/win32k/objects/bitmaps.c Sat Aug 11 10:29:31 2007
@@ -1075,7 +1075,7 @@
}
BOOL STDCALL
-NtGdiSetBitmapDimensionEx(
+NtGdiSetBitmapDimension(
HBITMAP hBitmap,
INT Width,
INT Height,
Modified: trunk/reactos/subsystems/win32/win32k/objects/brush.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/subsystems/win32/win32k/ob…
==============================================================================
--- trunk/reactos/subsystems/win32/win32k/w32ksvc.db (original)
+++ trunk/reactos/subsystems/win32/win32k/w32ksvc.db Sat Aug 11 10:29:31 2007
@@ -270,10 +270,10 @@
# NtGdiSelectPen 2
# NtGdiSetBitmapAttributes 2
NtGdiSetBitmapBits 3
-# NtGdiSetBitmapDimension 4
+NtGdiSetBitmapDimension 4
NtGdiSetBoundsRect 3
# NtGdiSetBrushAttributes 2
-# NtGdiSetBrushOrg 4
+NtGdiSetBrushOrg 4
NtGdiSetColorAdjustment 2
NtGdiSetColorSpace 2
NtGdiSetDeviceGammaRamp 2
@@ -694,10 +694,8 @@
#ReactOS specify syscall
NtGdiSelectObject 2
NtGdiSelectPalette 3
-NtGdiSetBitmapDimensionEx 4
NtGdiSetBkColor 2
NtGdiSetBkMode 2
-NtGdiSetBrushOrgEx 4
NtGdiSetDIBColorTable 4
NtGdiSetDIBits 7
NtGdiSetDIBitsToDevice 12
--- trunk/reactos/subsystems/win32/win32k/objects/brush.c (original)
+++ trunk/reactos/subsystems/win32/win32k/objects/brush.c Sat Aug 11 10:29:31 2007
@@ -694,9 +694,9 @@
}
/*
* NtGdiSetBrushOrgEx
*
* The NtGdiSetBrushOrgEx function sets the brush origin that GDI assigns to
* the next brush an application selects into the specified device context.
*
* Status
@@ -704,7 +704,7 @@
*/
BOOL STDCALL
-NtGdiSetBrushOrgEx(HDC hDC, INT XOrg, INT YOrg, LPPOINT Point)
+NtGdiSetBrushOrg(HDC hDC, INT XOrg, INT YOrg, LPPOINT Point)
{
PDC dc = DC_LockDc(hDC);
if (dc == NULL)
@@ -694,9 +694,9 @@
}
/*
- * NtGdiSetBrushOrgEx
- *
- * The NtGdiSetBrushOrgEx function sets the brush origin that GDI assigns to
+ * NtGdiSetBrushOrg
+ *
+ * The NtGdiSetBrushOrg function sets the brush origin that GDI assigns to
* the next brush an application selects into the specified device context.
*
Modified: trunk/reactos/subsystems/win32/win32k/w32ksvc.db
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/subsystems/win32/win32k/w3…
==============================================================================